import React, { Component } from 'react'
import { is, fromJS } from 'immutable'
import { InputNumber } from 'antd'

import MKEmitter from '@/utils/events.js'

// import './index.scss'

class MKNumberInput extends Component {
  constructor(props) {
    super(props)

    const config = props.config

    let precision = (config.decimal || config.decimal === 0) ? config.decimal : null
    
    this.state = {
      precision,
      value: config.initval
    }
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  componentDidMount () {
    MKEmitter.addListener('mkFC', this.mkFormHandle)
  }

  componentWillUnmount () {
    this.setState = () => {
      return
    }
    MKEmitter.removeListener('mkFC', this.mkFormHandle)
  }

  mkFormHandle = (type, uuid, value) => {
    if (uuid !== this.props.config.uuid) return

    if (type === 'focus') {
      let node = document.getElementById(uuid)
      node && node.select()
    } else if (type === 'input') {
      this.setState({value})
      this.props.onChange(value, true)
    }
  }

  handleChange = (val) => {
    this.setState({value: val})

    let _val = val

    if (typeof(_val) !== 'number') {
      _val = parseFloat(_val)

      if (isNaN(_val)) {
        _val = ''
      }
    }
    
    this.props.onChange(_val)
  }

  handleSubmit = () => {
    const { config } = this.props

    if (config.enter === 'false') return
    if (config.enter === 'tab') {
      MKEmitter.emit('mkFC', 'focus', config.tabUuid)
    } else {
      MKEmitter.emit('mkFC', 'focus', config.tabUuid)
      this.props.onSubmit(config.tabUuid)
    }
  }

  render() {
    const { config } = this.props
    const { value, precision } = this.state

    if (precision === null) {
      return (<InputNumber id={config.uuid} value={value} disabled={config.readonly} onChange={this.handleChange} onPressEnter={this.handleSubmit}/>)
    } else {
      return (<InputNumber id={config.uuid} value={value} precision={precision} disabled={config.readonly} onChange={this.handleChange} onPressEnter={this.handleSubmit} />)
    }
  }
}

export default MKNumberInput